@@ -14,13 +14,22 @@ from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAl
 from global_chem.materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
 from global_chem.materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
 
-# Medicinal Chemistry - International
+# Education
 
-from global_chem.medicinal_chemistry.chinese.how_to_live_longer import HowToLiveLonger
+from global_chem.education.cengage.organic_and_inorganic_bronsted_acids import OrganicAndInorganicBronstedAcids
+
+# Warfare
+
+from global_chem.warfare.organophosphorous_nerve_agents import OrganoPhosphorousNerveAgents
 
 # Medicinal Chemistry - Cannabinoids
 
-from global_chem.medicinal_chemistry.cannabinoids.cannabinoids import Cannabinoids
+from global_chem.medicinal_chemistry.cannabinoids.phytocannabinoids import PhytoCannabinoids
+from global_chem.medicinal_chemistry.cannabinoids.constituents_of_cannabis_sativa import ConstituentsOfCannabisSativa
+
+# Medicinal Chemistry - International
+
+from global_chem.medicinal_chemistry.chinese.how_to_live_longer import HowToLiveLonger
 
 # Medicinal Chemistry - Warheads
 
